@@ -65,13 +65,14 @@ def find_package_manager():
 
 
 def run_dependency_scanner(package_manager='', input_dir='', output_dir_file='', pip_activate_cmd='', pip_deactivate_cmd='',
-                           output_custom_dir='', app_name=const.default_app_name, github_token='', format=''):
+                           output_custom_dir='', app_name=const.default_app_name, github_token='', format='', direct=True):
     global logger
 
     ret = True
     sheet_list = {}
     sheet_list[_sheet_name] = []
     _json_ext = ".json"
+    _yaml_ext = ".yaml"
     _start_time = datetime.now().strftime('%y%m%d_%H%M%S')
 
     success, msg, output_path, output_file, output_extension = check_output_format(output_dir_file, format)
@@ -83,9 +84,11 @@ def run_dependency_scanner(package_manager='', input_dir='', output_dir_file='',
 
         if output_file == "":
             if output_extension == _json_ext:
-                output_file = "Opossum_input_" + _start_time
+                output_file = f"Opossum_input_{_start_time}"
+            elif output_extension == _yaml_ext:
+                output_file = f"fosslight-sbom-info_{_start_time}"
             else:
-                output_file = "FOSSLight-Report_" + _start_time
+                output_file = f"FOSSLight-Report_{_start_time}"
     else:
         logger.error(msg)
         sys.exit(1)
@@ -137,11 +140,17 @@ def run_dependency_scanner(package_manager='', input_dir='', output_dir_file='',
     else:
         found_package_manager[package_manager] = ''
 
+    pass_key = 'PASS'
     for pm, manifest_file_name in found_package_manager.items():
+        if manifest_file_name == pass_key:
+            continue
         ret, package_sheet_list = analyze_dependency(pm, input_dir, output_path, pip_activate_cmd, pip_deactivate_cmd,
-                                                     output_custom_dir, app_name, github_token, manifest_file_name)
+                                                     output_custom_dir, app_name, github_token, manifest_file_name, direct)
         if ret:
             sheet_list[_sheet_name].extend(package_sheet_list)
+            if pm == const.GRADLE:
+                if const.ANDROID in found_package_manager.keys():
+                    found_package_manager[const.ANDROID] = pass_key
 
     if sheet_list is not None:
         output_file_without_ext = os.path.join(output_path, output_file)
@@ -169,6 +178,7 @@ def main():
     app_name = const.default_app_name
     github_token = ''
     format = ''
+    direct = True
 
     parser = argparse.ArgumentParser(add_help=False)
     parser.add_argument('-h', '--help', action='store_true', required=False)
@@ -182,6 +192,7 @@ def main():
     parser.add_argument('-n', '--appname', nargs=1, type=str, required=False)
     parser.add_argument('-t', '--token', nargs=1, type=str, required=False)
     parser.add_argument('-f', '--format', nargs=1, type=str, required=False)
+    parser.add_argument('--direct', choices=('true', 'false'), default='True', required=False)
 
     args = parser.parse_args()
 
@@ -211,9 +222,14 @@ def main():
         github_token = ''.join(args.token)
     if args.format:  # -f option
         format = ''.join(args.format)
+    if args.direct:  # --direct option
+        if args.direct == 'true':
+            direct = True
+        elif args.direct == 'false':
+            direct = False
 
     run_dependency_scanner(package_manager, input_dir, output_dir, pip_activate_cmd, pip_deactivate_cmd,
-                           output_custom_dir, app_name, github_token, format)
+                           output_custom_dir, app_name, github_token, format, direct)
 
 
 if __name__ == '__main__':
